@@ -21,6 +21,7 @@ from rest_framework import routers
 from django.urls import path
 from data.views.views import HardwareViewSet, AccessoryViewSet, CalibrationViewSet, ChannelViewSet, HubViewSet, \
     IOViewSet
+from django.contrib.auth import views as auth_views
 
 # Routers provide an easy way of automatically determining the URL conf.
 router = routers.DefaultRouter()
@@ -32,11 +33,13 @@ router.register(r'hubs', HubViewSet)
 router.register(r'io', IOViewSet)
 
 from data.views.views import index
+from data.views.views import video_streams
 
 # Wire up our API using automatic URL routing.
 # Additionally, we include login URLs for the browsable API.
 urlpatterns = [
     path('', include(router.urls)),
+    url(r'^login/$', auth_views.login, name='login'),
     path('api-auth/', include('rest_framework.urls', namespace='rest_framework')),
     # path('start', views.start, name='start'),
     # path('calibrate', views.start, name='calibrate'),
@@ -56,7 +59,6 @@ urlpatterns = [
     path('delete/ajax/hardware', HardwareViewSet.deleteHardware, name="delete_hardware"),
     path('delete/ajax/io', IOViewSet.deleteIO, name="delete_io"),
 
-
     path('post/ajax/hardware/io/', HardwareViewSet.postHardwareIO,
          name="post_hardware_io"),
     path('post/ajax/calibrationconstant', CalibrationViewSet.postCalibrationConstant, name="post_calibration_constant"),
@@ -68,7 +70,6 @@ urlpatterns = [
     path('hardwares/<uuid:hardware_id>/channels', HardwareViewSet.getChannels),
     path('channels/<uuid:channel_id>/io', ChannelViewSet.listIO),
 
-
     # path('<str:room_name>/', views.room, name='room'),
     path('post/ajax/hub', HubViewSet.postHub, name="post_hub"),
     path('hub/', csrf_exempt(HubViewSet.postHub)),
@@ -78,5 +79,6 @@ urlpatterns = [
     path('hub/<uuid:hub_id>/channels', HubViewSet.listHubChannels),
     path('hub/<uuid:hub_id>/accessories', HubViewSet.listHubAccessories),
     path('openhubapi/about', HubViewSet.about),
+    path('streams/', video_streams, name="video_streams"),
 
 ]
